/*
 * Copyright 2015-2024 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.protocol;


/**
 * <p>
 * Base class for <code>CA_PROTO_EVENT_ADD</code> messages.
 * </p>
 * 
 * <p>
 * This message type is used by clients to request an event subscription and by
 * servers for subscription events or to confirm the cancellation of a request
 * subscription. As the format of the two server variants is different, there
 * are two classes for them. {@link ChannelAccessSubscriptionServerMessage} is
 * used to send a subscription event and
 * {@link ChannelAccessCancelSubscriptionServerMessage} is used to confirm a
 * cancellation request. In some cases, the on-wire format of these messages is
 * identical, so the code handling the message must infer its meaning and handle
 * it accordingly.
 * </p>
 * 
 * @see ChannelAccessCommand#CA_PROTO_EVENT_ADD
 * 
 * @author Sebastian Marsching
 */
public abstract class ChannelAccessSubscriptionMessage extends
        ChannelAccessMessage {

    /**
     * Constructor. This constructor only sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_EVENT_ADD}. All other fields depend
     * on the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     */
    ChannelAccessSubscriptionMessage() {
        super(ChannelAccessCommand.CA_PROTO_EVENT_ADD);
    }

    /**
     * Constructor. This constructor sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_EVENT_ADD} and stores the message
     * header that is used to construct this message. All other fields depend on
     * the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     * 
     * @param messageHeader
     *            the message header that is used to for creating this message.
     *            This header is passed on to the
     *            {@link ChannelAccessMessage#ChannelAccessMessage(ChannelAccessCommand, ChannelAccessMessageHeader)}
     *            constructor.
     */
    ChannelAccessSubscriptionMessage(ChannelAccessMessageHeader messageHeader) {
        super(ChannelAccessCommand.CA_PROTO_EVENT_ADD, messageHeader);
    }

}
